.. _plot_ref:

Plotting functions
==================

Cartography
-----------
.. automodule:: aeolus.plot.cart
   :members:

Matplotlib helpers
------------------
.. automodule:: aeolus.plot.mpl
   :members:

Text-related functions
----------------------
.. automodule:: aeolus.plot.text
   :members:


.. _pyvista_ref:

PyVista interface
-----------------
.. automodule:: aeolus.plot.pv
   :members:
